var SHEditor;
(function (SHEditor) {
    /**
     * 输入文字标签变化
     *
     * @export
     */
    function onTextTagChanged(handler) {
        SHJSBridge.addEventListener("textTagChange", (content) => {
            handler(content);
        });
    }
    SHEditor.onTextTagChanged = onTextTagChanged;
    /**
     * 通知客户端标签变化
     *
     * @export
     */
    function triggerTextTagChange(tagStatus) {
        SHJSBridge.sendMessage("textTagChange", tagStatus);
    }
    SHEditor.triggerTextTagChange = triggerTextTagChange;
    SHEditor.VisibleSize = {
        width: 0,
        height: 0,
    };
    SHJSBridge.addEventListener("updateVisibleSize", (content) => {
        SHEditor.VisibleSize = content;
    });
    function onRichTextContentUpdate(handler) {
        SHJSBridge.addEventListener("updateRichTextContent", (htmlString) => {
            handler(htmlString);
        });
    }
    SHEditor.onRichTextContentUpdate = onRichTextContentUpdate;
    function getRichTextContent(handler) {
        SHJSBridge.addEventListener("getRichTextContent", (content, complete) => {
            handler((htmlString) => {
                complete(htmlString);
            });
        });
    }
    SHEditor.getRichTextContent = getRichTextContent;
    function updateTextCount(textCount) {
        SHJSBridge.sendMessage("textCountChange", textCount);
    }
    SHEditor.updateTextCount = updateTextCount;
})(SHEditor || (SHEditor = {}));
var SHEditor;
(function (SHEditor) {
    let ImageStatus;
    (function (ImageStatus) {
        ImageStatus[ImageStatus["uploading"] = 0] = "uploading";
        ImageStatus[ImageStatus["failed"] = 1] = "failed";
        ImageStatus[ImageStatus["success"] = 2] = "success";
    })(ImageStatus = SHEditor.ImageStatus || (SHEditor.ImageStatus = {}));
    class ImageContext {
        constructor(data) {
            this.token = data.token;
            this.size = data.size;
            this.status = data.status;
            this.url = data.url;
            this.onDelete = data.onDelete;
        }
        retry() {
            if (this.status == ImageStatus.success && this.url) {
                console.warn(`图片已经上传成功了！URL: ${this.url}`);
                return;
            }
            SHJSBridge.sendMessage("uploadImage", { "token": this.token });
        }
        delete() {
            this.onDelete(this);
            SHJSBridge.sendMessage("deleteImage", { "token": this.token });
        }
        edit() {
            SHJSBridge.sendMessage("editImage", { "token": this.token });
        }
    }
    SHEditor.ImageContext = ImageContext;
    function createUUID() {
        return 'xxxxxxxx-xxxx-4xxx-yxxx-xxxxxxxxxxxx'.replace(/[xy]/g, function (c) {
            var r = Math.random() * 16 | 0, v = c == 'x' ? r : (r & 0x3 | 0x8);
            return v.toString(16);
        });
    }
    class ImageManager {
        constructor() {
            this.imageContextList = {};
            SHJSBridge.addEventListener(`imageStatusChange`, (content) => {
                let self = this;
                let token = content.token;
                let context = this.imageContextList[token];
                if (!context) {
                    context = new ImageContext(Object.assign(content, {
                        onDelete: (ctx) => {
                            self.deleteImageWithContext(ctx);
                        }
                    }));
                    this.imageContextList[token] = context;
                    this.insertImageHandler(context);
                }
                else {
                    context.status = content.status;
                    context.size = content.size;
                    context.url = content.url;
                    context.error = content.error;
                    if (context.onStatusChange) {
                        context.onStatusChange();
                    }
                }
            });
        }
        insertImageWithContext(handler) {
            this.insertImageHandler = handler;
        }
        deleteImageWithContext(context) {
            delete this.imageContextList[context.token];
        }
        createImageContext(content) {
            let self = this;
            let context = new ImageContext(Object.assign(content, {
                token: createUUID(),
                status: ImageStatus.success,
                onDelete: (ctx) => {
                    self.deleteImageWithContext(ctx);
                }
            }));
            this.imageContextList[context.token] = context;
            SHJSBridge.sendMessage("createImageContext", {
                token: context.token,
                size: context.size,
                url: context.url,
                status: ImageStatus.success
            });
            return context;
        }
    }
    let imageManager = new ImageManager();
    function onImageInsert(handler) {
        imageManager.insertImageWithContext(handler);
    }
    SHEditor.onImageInsert = onImageInsert;
    function createImageContext(content) {
        return imageManager.createImageContext(content);
    }
    SHEditor.createImageContext = createImageContext;
})(SHEditor || (SHEditor = {}));
